<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>

SPDX-License-Identifier: GPL-2.0-or-later
-->

# fedrq.backends.dnf.backend

::: fedrq.backends.dnf.backend

## See also

- [`dnf.Base`][dnf.Base]
- [`dnf.package.Package`][dnf.package.Package]
- [`dnf.query.Query`][dnf.query.Query]
- [`dnf.exceptions.RepoError`][dnf.exceptions.RepoError]
